@@ -1,14 +1,9 @@
 """
-tests for quantecon.util
+Tests for quantecon.util
 
 """
-from __future__ import division
-from collections import Counter
-import unittest
 import numpy as np
 from numpy.testing import assert_allclose
-from nose.plugins.attrib import attr
-import pandas as pd
 from quantecon import matrix_eqn as qme
 
 
@@ -31,3 +26,14 @@ def test_solve_discrete_lyapunov_B():
 
     assert_allclose(B, X)
 
+def test_solve_discrete_lyapunov_complex():
+    'Complex test, A is companion matrix'
+    A = np.array([[0.5 + 0.3j, 0.1 + 0.1j],
+                  [         1,          0]])
+    B = np.eye(2)
+
+    X = qme.solve_discrete_lyapunov(A, B)
+
+    assert_allclose(np.dot(np.dot(A, X), A.conj().transpose()) - X, -B,
+                    atol=1e-15)
+
